@@ -32,6 +32,9 @@ sub creation_filled { return qw(public_url created_at); }
 sub update_filled { return qw(updated_at); }
 sub create_method { return "PUT"; }
 
+sub read_scope { return "read_themes"; }
+sub write_scope { return "write_themes"; }
+
 eval(__PACKAGE__->generate_accessors); die $@ if $@;
 
 1
