@@ -18,6 +18,9 @@ BEGIN { $fields = {
 sub creation_minimal { return qw(path target); }
 sub creation_filled { return qw(id); }
 
+sub read_scope { return "read_content"; }
+sub write_scope { return "write_content"; }
+
 eval(__PACKAGE__->generate_accessors); die $@ if $@;
 
 1
